local PotatoTweaks = Apollo.GetAddon("PotatoTweaks")
local tTweak1 = {
	name="Chat Loot Links",
	description="Adds link and item color to loot chat messages.",
	boolean="bChatLinks",
	func="ChatTweak",
	dependencies={"ChatLog", "MasterLoot"}
}
local tTweak2 = {
	name="Remove Loot Rolls",
	description="Removes unnecssary roll chat message spam on Need v Greed rolls.",
	boolean="bNoLootSpam",
	func="ChatTweak",
	dependencies={"NeedVsGreed","TLoot"}
}
local tTweak3 = {
	name="FailCheck Death Colors",
	description="Colors FailCheck death reports to distinguish from actual party chat.",
	boolean="bFailCheckColor",
	func="ChatTweak",
	dependencies={"ChatLog"}
}
table.insert(PotatoTweaks.tTweaks,tTweak1)
table.insert(PotatoTweaks.tTweaks,tTweak2)
table.insert(PotatoTweaks.tTweaks,tTweak3)

function PotatoTweaks:ChatTweak()
	local ChatLog = Apollo.GetAddon("ChatLog")	
	if ChatLog then
		local OnCombatLogLoot = function(self, tEventArgs, bLink)
			local strResult = ""
			if tEventArgs.monLoot then
				strResult = String_GetWeaselString(Apollo.GetString("CombatLog_LootReceived"), tEventArgs.monLoot:GetMoneyString())
				ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, strResult)
			end

			if tEventArgs.itemLoot and tEventArgs.nItemAmount > 0 then
				local strArgItemName = bLink and tEventArgs.itemLoot:GetChatLinkString() or tEventArgs.itemLoot:GetName()
				local strItemName = Apollo.GetString("CombatLog_SpellUnknown")
				if strArgItemName and strArgItemName ~= "" then
					strItemName = strArgItemName
				end

				if tEventArgs.nItemAmount > 1 then
					strItemName = String_GetWeaselString(Apollo.GetString("CombatLog_MultiItem"), tEventArgs.nItemAmount, strItemName)
				end

				strResult = String_GetWeaselString(Apollo.GetString("CombatLog_LootReceived"), strItemName)

				ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, strResult)
			end
		end
			--[[local strResult = ""
			if tEventArgs.monLoot then
				strResult = String_GetWeaselString(Apollo.GetString("CombatLog_LootReceived"), tEventArgs.monLoot:GetMoneyString())
				ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, strResult)
			end
		
			if tEventArgs.nItemAmount > 0 and tEventArgs.itemLoot then
				local strArgItemName = bLink and tEventArgs.itemLoot:GetChatLinkString() or tEventArgs.itemLoot:GetName()
				local strItemName = Apollo.GetString("CombatLog_SpellUnknown")
				if strArgItemName and strArgItemName ~= "" then
					strItemName = strArgItemName
				end
		
				if tEventArgs.nItemAmount > 1 then
					strItemName = String_GetWeaselString(Apollo.GetString("CombatLog_MultiItem"), tEventArgs.nItemAmount, strItemName)
				end
		
				strResult = String_GetWeaselString(Apollo.GetString("CombatLog_LootReceived"), strItemName)
		
				ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, strResult)
			end
		end--]]
		
		local OnChatMessage = function(self, channelCurrent, tMessage)
			local tQueuedMessage = {}
			tQueuedMessage.tMessage = tMessage
			tQueuedMessage.eChannelType = channelCurrent:GetType()
			tQueuedMessage.strChannelName = channelCurrent:GetName()
			tQueuedMessage.strChannelCommand = channelCurrent:GetCommand()
			tQueuedMessage.idChannel = channelCurrent:GetUniqueId()

			-- handle unit bubble if needed.
			if tQueuedMessage.tMessage.unitSource and tQueuedMessage.tMessage.bShowChatBubble then
				self:HelperGenerateChatMessage(tQueuedMessage)
				if tQueuedMessage.xmlBubble then
					tMessage.unitSource:AddTextBubble(tQueuedMessage.xmlBubble)
				end
			end
			if channelCurrent:GetName() == "Party" then
				for key,val in pairs(tMessage.arMessageSegments) do
					if string.find(val.strText, "%[Death%]") then
						tQueuedMessage.eChannelType = ChatSystemLib.ChatChannel_Yell
						Sound.Play(205)
					end
				end
			end
			self:HelperQueueMessage(tQueuedMessage)
		end
		local bFailCheckColor = self.bFailCheckColor
		ChatLog.OnChatMessage = function(self, channelCurrent, tMessage)
			OnChatMessage(self, channelCurrent, tMessage)
		end
		local bChatLinks = self.bChatLinks
		ChatLog.OnCombatLogLoot = function(self, tEventArgs)
			OnCombatLogLoot(self, tEventArgs, bChatLinks)
		end
	end
	
	local MasterLoot = Apollo.GetAddon("MasterLoot")
	if MasterLoot then
		local OnLootAssigned = function (self, itemLooted, strLooter, bLink)
			local strItemName = bLink and itemLooted:GetChatLinkString() or itemLooted:GetName()
			Event_FireGenericEvent("GenericEvent_LootChannelMessage", String_GetWeaselString(Apollo.GetString("CRB_MasterLoot_AssignMsg"), strItemName, strLooter))
		end
		
		local bChatLinks = self.bChatLinks
		MasterLoot.OnLootAssigned = function(self, objItem, strLooter)
			OnLootAssigned(self, objItem, strLooter, bChatLinks)
		end
	end
	
	local TLoot = Apollo.GetAddon("TLoot")
	local NeedVsGreed = Apollo.GetAddon("NeedVsGreed")
	
	local OnLootRollAllPassed = function(self, itemLoot, bLink, bNoLootSpam)
		local strItemName = bLink and itemLoot:GetChatLinkString() or itemLoot:GetName()
		if not bNoLootSpam then
			ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, String_GetWeaselString(Apollo.GetString("NeedVsGreed_EveryonePassed"), strItemName))
		else
			--Print("OnLootRollAllPassed Suppressed")
		end
	end
	
	local OnLootRollWon = function(self, itemLoot, strWinner, bNeed, bLink)
		local strItemName = bLink and itemLoot:GetChatLinkString() or itemLoot:GetName()
		local strNeedOrGreed = bNeed and Apollo.GetString("NeedVsGreed_NeedRoll") or Apollo.GetString("NeedVsGreed_GreedRoll")
		ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, String_GetWeaselString(Apollo.GetString("NeedVsGreed_ItemWon"), strWinner, strItemName, strNeedOrGreed))
	end
	
	local OnLootRollSelected = function(self, itemLoot, strPlayer, bNeed, bLink, bNoLootSpam)
		local strItemName = bLink and itemLoot:GetChatLinkString() or itemLoot:GetName()
		local strNeedOrGreed = bNeed and Apollo.GetString("NeedVsGreed_NeedRoll") or Apollo.GetString("NeedVsGreed_GreedRoll")
		if not bNoLootSpam then
			ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, String_GetWeaselString(Apollo.GetString("NeedVsGreed_LootRollSelected"), strPlayer, strNeedOrGreed, strItemName))
		else
			--Print("OnLootRollSelected Suppressed")
		end
	end
	
	local OnLootRoll = function(self, itemLoot, strPlayer, nRoll, bNeed, bLink, bNoLootSpam)
		local strItemName = bLink and itemLoot:GetChatLinkString() or itemLoot:GetName()
		local strNeedOrGreed = bNeed and Apollo.GetString("NeedVsGreed_NeedRoll") or Apollo.GetString("NeedVsGreed_GreedRoll")
		if not bNoLootSpam then
			ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, String_GetWeaselString(Apollo.GetString("NeedVsGreed_OnLootRoll"), strPlayer, nRoll, itemLoot:GetChatLinkString(), strNeedOrGreed))
		else
			--Print("OnLootRoll Suppressed")
		end
	end
	
	if NeedVsGreed then
		local bChatLinks = self.bChatLinks
		local bNoLootSpam = self.bNoLootSpam
		
		NeedVsGreed.OnLootRollAllPassed = function(self, itemLooted)
			OnLootRollAllPassed(self, itemLooted, bChatLinks, bNoLootSpam)
		end
		NeedVsGreed.OnLootRollWon = function(self, itemLooted, strWinner, bNeed)
			OnLootRollWon(self, itemLooted, strWinner, bNeed, bChatLinks)
		end
		NeedVsGreed.OnLootRollSelected = function(self, itemLooted, strPlayer, bNeed)
			OnLootRollSelected(self, itemLooted, strPlayer, bNeed, bChatLinks, bNoLootSpam)
		end
		NeedVsGreed.OnLootRoll = function(self, itemLooted, strPlayer, nRoll, bNeed)
			OnLootRoll(self, itemLooted, strPlayer, nRoll, bNeed, bChatLinks, bNoLootSpam)
		end
	elseif TLoot then
		local bChatLinks = self.bChatLinks
		local bNoLootSpam = self.bNoLootSpam
		
		TLoot.OnLootRollAllPassed = function(self, itemLooted)
			--TL
			local wndItemContainer = self:GetLootWindowForItem(itemLooted)
			if wndItemContainer ~= nil then
				local data = wndItemContainer:GetData()
				data.nTimeCompleted = os.clock()
				wndItemContainer:SetData(data)
			else
				--Logger:warn("Could not find loot window for item %s", itemLooted:GetName())
			end
			
			self:RemoveItemRollData(itemLooted)
			--/TL
			OnLootRollAllPassed(self, itemLooted, bChatLinks, bNoLootSpam)
		end
		TLoot.OnLootRollWon = function(self, itemLooted, strWinner, bNeed)
			--TL
			self:AddItemWinner(itemLooted, strWinner)
			local wndItemContainer = self:GetLootWindowForItem(itemLooted)
			if wndItemContainer ~= nil then
				local data = wndItemContainer:GetData()
				data.nTimeCompleted = os.clock()
				wndItemContainer:SetData(data)
			else
				--Logger:warn("Could not find loot window for item %s", itemLooted:GetName())
			end
			
			self:RemoveItemRollData(itemLooted)
			--/TL
			OnLootRollWon(self, itemLooted, strWinner, bNeed, bChatLinks)
		end
		TLoot.OnLootRollSelected = function(self, itemLooted, strPlayer, bNeed)
			--TL
			--Logger:debug("OnLootRollSelected (i=%s, p=%s, n=%s)", itemLooted:GetName(), strPlayer, tostring(bNeed))
			local _, nRollType = self:GetNeedOrGreedString(bNeed)
			
			self:AddItemRollType(itemLooted, strPlayer, nRollType)
			--/TL
			
			OnLootRollSelected(self, itemLooted, strPlayer, bNeed, bChatLinks, bNoLootSpam)
		end
		TLoot.OnLootRoll = function(self, itemLooted, strPlayer, nRoll, bNeed)
			--TL
			--Logger:debug("OnLootRoll (i=%s, p=%s, r=%s, n=%s)", itemLooted:GetName(), sPlayer, tostring(nRoll), tostring(bNeed))			
			self:AddItemRoll(itemLooted, strPlayer, nRoll)
			--/TL
			OnLootRoll(self, itemLooted, strPlayer, nRoll, bNeed, bChatLinks, bNoLootSpam)
		end		
	end
	
end


