-----------------------------------------------------------------------------------------------
-- Client Lua Script for PotatoTweaks
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- PotatoTweaks Module Definition
-----------------------------------------------------------------------------------------------
local PotatoTweaks = {} 
PotatoTweaks.tTweaks = {}
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function PotatoTweaks:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function PotatoTweaks:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- PotatoTweaks OnLoad
-----------------------------------------------------------------------------------------------
function PotatoTweaks:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("PotatoTweaks.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- PotatoTweaks OnDocLoaded
-----------------------------------------------------------------------------------------------
local tOriginalFunctions = {}

function PotatoTweaks:OnDocLoaded()
	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "PotatoTweaksForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)
		
		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("pt", "OnSlashCommand", self)
		Apollo.LoadSprites("TweakSprites.xml", "TweakSprites")
		
		self.nLoadTimer = self.nLoadTimer or 7
		
		self.timerOnLoad = ApolloTimer.Create(self.nLoadTimer, false, "OnTimerLoad", self)
		-- Do additional Addon initialization here
	end
end

function PotatoTweaks:OnSlashCommand()
	self.wndMain:Show(not self.wndMain:IsShown())
end

function PotatoTweaks:OnSave(eLevel)
	if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then return end
	
	local tData = {}
	for key,val in pairs(self) do
		if string.find(key, "b") == 1 then
			tData[key] = val
		end
		--[[if string.find(key, "settings") then
			tData[key] = val
		end--]]
	end
	
	return tData
end

function PotatoTweaks:OnRestore(eLevel, tData)
	if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then return end
	
	for key,val in pairs(tData) do
		self[key] = val
	end
end

function PotatoTweaks:OnTimerLoad()
	Print("Loading PotatoTweaks")
	local tDisabled = {}
	for _, tTweak in pairs(self.tTweaks) do
		local bLoad = false
		for idx, strAddonName in pairs(tTweak.dependencies) do
			if Apollo.GetAddon(strAddonName) ~= nil then
				bLoad = true
				break
			end
		end
		
		if bLoad then
			if self[tTweak.boolean] == nil then
				self[tTweak.boolean] = true
			end
			self:CreateTweakItem(tTweak)
			if self[tTweak.func] then
				self[tTweak.func](self)
			end
		else
			table.insert(tDisabled, tTweak)
		end
	end
	for _, tTweak in pairs(tDisabled) do
		local wndTweak = self:CreateTweakItem(tTweak)
		
		local wndDisabled = Apollo.LoadForm(self.xmlDoc, "TweakDisabled", wndTweak, self)
		local strDependencies = ""
		for idx, strAddonName in pairs(tTweak.dependencies) do
			strDependencies = strDependencies..strAddonName
			if idx ~= #tTweak.dependencies then
				strDependencies = strDependencies..", "
			end
		end
		wndDisabled:FindChild("Dependencies"):SetText(strDependencies)
	end
	self.wndMain:FindChild("MainWindow:Tweaks"):ArrangeChildrenVert()
end

function PotatoTweaks:CreateTweakItem(tTweak)
	local wndTweak = Apollo.LoadForm(self.xmlDoc, "TweakItem", self.wndMain:FindChild("MainWindow:Tweaks"), self)
	wndTweak:FindChild("TweakName"):SetText(tTweak.name)
	wndTweak:FindChild("TweakDescription"):SetText(tTweak.description)
	wndTweak:FindChild("Check"):Show(self[tTweak.boolean])
	wndTweak:SetCheck(self[tTweak.boolean])
	wndTweak:SetData(tTweak)
	
	if tTweak.settings then
		local wndSettings = Apollo.LoadForm(self.xmlDoc, "TweakSettings", wndTweak, self)
		wndTweak:FindChild("SettingsBtn"):Show(true)
		wndTweak:FindChild("SettingsBtn"):AttachWindow(wndSettings)
		for _,tField in pairs(tTweak.settings) do
			if tField.type == "radio" then
				self:CreateRadioButton(wndSettings:FindChild("Container"), tField)
			--[[elseif tField.type == "slider" then
			
			else--]]
			
			end
		end
		wndSettings:FindChild("Container"):ArrangeChildrenVert()
	end

	return wndTweak
end

function PotatoTweaks:CreateRadioButton(wndParent, tField)
	local wndRadio = Apollo.LoadForm(self.xmlDoc, "radio", wndParent, self)
	wndRadio:SetText(tField.text)
	wndRadio:SetData(tField.var)
	if self[tField.var] == nil then
		self[tField.var] = true		
	end
	wndRadio:SetCheck(self[tField.var])
end

function PotatoTweaks:ToggleRadioButton(wndHandler, wndControl, eMouseButton)
	local strVar = wndHandler:GetData()
	self[strVar] = wndHandler:IsChecked()
	Print("[PotatoTweaks] /reloadui to save and apply settings.")
end

function PotatoTweaks:OnTweakToggle(wndHandler)
	local bChecked = wndHandler:IsChecked()
	local tTweak = wndHandler:GetData()
	wndHandler:FindChild("Check"):Show(bChecked)
	self[tTweak.boolean] = bChecked
	if self[tTweak.func] then
		self[tTweak.func](self)
	end
end

function PotatoTweaks:OnCancel()
	self.wndMain:Close()
end

-----------------------------------------------------------------------------------------------
-- PotatoTweaksForm Functions
-----------------------------------------------------------------------------------------------

function PotatoTweaks:OnTweakCheck( wndHandler, wndControl, eMouseButton )
	self:OnTweakToggle(wndHandler)
end

function PotatoTweaks:OnTweakUncheck( wndHandler, wndControl, eMouseButton )
	self:OnTweakToggle(wndHandler)	
end

---------------------------------------------------------------------------------------------------
-- PotatoTweaks Instance
---------------------------------------------------------------------------------------------------
local PotatoTweaksInst = PotatoTweaks:new()
PotatoTweaksInst:Init()
